@@ -16,6 +16,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # Import from the standard library
+from logging import basicConfig
 from sys import version_info
 
 # Import from feedstail
@@ -31,6 +32,7 @@ class Config(Storage):
         self.oneshot = False
         self.key = 'id'
         self.reverse = False
+        self.number = None
 
         if version_info < (2, 6):
             self.format = u'Title: %(title)s'
@@ -39,3 +41,5 @@ class Config(Storage):
 
 
 config = Config()
+basicConfig(format='%(levelname)s: %(message)s')
+
